@@ -276,11 +276,12 @@ class Type(sequence_ordered(), tree(separator='\\'), ModelSQL, ModelView):
         childs = [self]
         while childs:
             for child in childs:
-                if child.template and not child.template_override:
-                    vals = child.template._get_type_value(type=child)
-                    if vals:
-                        values.append([child])
-                        values.append(vals)
+                if child.template:
+                    if not child.template_override:
+                        vals = child.template._get_type_value(type=child)
+                        if vals:
+                            values.append([child])
+                            values.append(vals)
                     template2type[child.template.id] = child.id
             childs = sum((c.childs for c in childs), ())
         if values:
@@ -581,7 +582,7 @@ class Account(ActivePeriodMixin, tree(), ModelSQL, ModelView):
             ('id', '!=', Eval('currency', -1)),
             ],
         states={
-            'reaodnly': _states['readonly'],
+            'readonly': _states['readonly'],
             'invisible': (Eval('kind').in_(
                     ['payable', 'revenue', 'receivable', 'expense'])
                 | ~Eval('deferral', False)),
@@ -941,7 +942,8 @@ class Account(ActivePeriodMixin, tree(), ModelSQL, ModelView):
         'reconcile', 'kind', 'deferral', 'party_required',
         'general_ledger_balance', 'taxes']
 
-    @fields.depends('parent', *__on_change_parent_fields)
+    @fields.depends('parent', *(__on_change_parent_fields
+            + ['_parent_parent.%s' % f for f in __on_change_parent_fields]))
     def on_change_parent(self):
         if not self.parent:
             return
@@ -1032,19 +1034,20 @@ class Account(ActivePeriodMixin, tree(), ModelSQL, ModelView):
         childs = [self]
         while childs:
             for child in childs:
-                if child.template and not child.template_override:
-                    vals = child.template._get_account_value(account=child)
-                    current_type = child.type.id if child.type else None
-                    if child.template.type:
-                        template_type = template2type.get(
-                            child.template.type.id)
-                    else:
-                        template_type = None
-                    if current_type != template_type:
-                        vals['type'] = template_type
-                    if vals:
-                        values.append([child])
-                        values.append(vals)
+                if child.template:
+                    if not child.template_override:
+                        vals = child.template._get_account_value(account=child)
+                        current_type = child.type.id if child.type else None
+                        if child.template.type:
+                            template_type = template2type.get(
+                                child.template.type.id)
+                        else:
+                            template_type = None
+                        if current_type != template_type:
+                            vals['type'] = template_type
+                        if vals:
+                            values.append([child])
+                            values.append(vals)
                     template2account[child.template.id] = child.id
             childs = sum((c.childs for c in childs), ())
         if values:
